@@ -178,7 +178,7 @@ impl Transaction for GenTransaction {
     }
 
     fn get_extension(&mut self) -> Box<dyn Any + Send + Sync> {
-        std::mem::replace(&mut self.ext, Box::new(0))
+        std::mem::replace(&mut self.ext, Box::new(()))
     }
 }
 
